# Buildsystem Integration

**The latest version of this documentation is available on [GitHub](https://github.com/Microsoft/vcpkg/tree/master/docs/users/buildsystems/integration.md).**

vcpkg supports use from any buildsystem and has specific native integration into MSBuild and CMake.

- [MSBuild Integration (Visual Studio)](msbuild-integration.md)
- [CMake Integration](cmake-integration.md)
- [Manual Integration](manual-integration.md)
- [`export` Command](export-command.md)
